@@ -23,9 +23,11 @@ class TxConvertTransfer(SessionBase):
 
     @staticmethod
     def get(convert_tx_hash):
-        q = TxConvertTransfer.session.query(TxConvertTransfer)
+        session = SessionBase.create_session()
+        q = session.query(TxConvertTransfer)
         q = q.filter(TxConvertTransfer.convert_tx_hash==convert_tx_hash)
         r = q.first()
+        session.close()
         if r == None:
             raise UnknownConvertError(convert_tx_hash)
         return r
