@@ -13,23 +13,9 @@ from ..enum import TxTypeEnum
 from .otx import Otx
 
 
-class Tx(SessionBase):
-    __tablename__ = 'tx'
-
-    date_added = Column(DateTime, default=datetime.datetime.utcnow)
-    tx_hash = Column(String(66))
-    success = Column(Boolean())
-
-
-    def __init__(self, tx_hash, success):
-        self.tx_hash = tx_hash
-        self.success = success
-
-
 class TxCache(SessionBase):
     __tablename__ = 'tx_cache'
 
-    tx_id = Column(Integer, ForeignKey('tx.id'))
     otx_id = Column(Integer, ForeignKey('otx.id'))
     source_token_address = Column(String(42))
     destination_token_address = Column(String(42))
@@ -43,26 +29,12 @@ class TxCache(SessionBase):
     date_created = Column(DateTime, default=datetime.datetime.utcnow)
 
 
-    def sync(self, tx_hash):
+    def __init__(self, tx_hash, sender, recipient, source_token_address, destination_token_address, from_value, to_value, block_number=None, tx_index=None):
         session = TxCache.create_session()
-        tx = session.query(Tx).filter(Tx.tx_hash==tx_hash).first()
+        tx = session.query(Otx).filter(Otx.tx_hash==tx_hash).first()
         if tx == None:
-            raise FileNotFoundError('confirmed transaction record unknown {} (add a Tx first)'.format(tx_hash))
-        self.tx_id = tx.id
-        session.close()
-        return tx
-
-
-    def __init__(self, tx_hash, sender, recipient, source_token_address, destination_token_address, from_value, to_value, block_number=None, tx_index=None, outgoing=False):
-        session = TxCache.create_session()
-        tx = None
-        if outgoing:
-            tx = session.query(Otx).filter(Otx.tx_hash==tx_hash).first()
-            if tx == None:
-                raise FileNotFoundError('outgoing transaction record unknown {} (add a Tx first)'.format(tx_hash))
-            self.otx_id = tx.id
-        else:
-            tx = self.sync(tx_hash)
+            raise FileNotFoundError('outgoing transaction record unknown {} (add a Tx first)'.format(tx_hash))
+        self.otx_id = tx.id
 
         if tx == None:
             raise ValueError('tx hash {} (outgoing: {}) not found'.format(tx_hash, outgoing))
@@ -84,17 +56,3 @@ class TxCache(SessionBase):
         txc = session.query(TxCache).order_by(TxCache.block_number.desc(), TxCache.tx_index.desc()).first()
         session.close()
         return txc
-
-#
-#class TxCacheAssoc(SessionBase):
-#
-#    __tablename__ = 'tx_cache_assoc'
-#
-#    otx_id = Column(Integer, ForeignKey('otx.id'), primary_key=True),
-#    tx_id = Column(Integer, ForeignKey('tx.id'), primary_key=True),
-#    cache_id = Column(Integer, ForeignKey('tx_cache.id'), primary_key=True),
-#    otx = relationship(Otx, backref=backref('otx_assoc'))
-#
-#    def __init__(self, cache_id):
-#        txa = TxCacheAssoc()
-#        txa.cache_id = cache_id
