@@ -34,14 +34,15 @@ def unpack_signed_raw_tx(tx_raw_bytes, chain_id):
 
     return {
         'from': a,
-        'nonce': int.from_bytes([0], 'big'),
-        'gasPrice': int.from_bytes([1], 'big'),
-        'gas': int.from_bytes([2], 'big'),
+        'nonce': int.from_bytes(d[0], 'big'),
+        'gasPrice': int.from_bytes(d[1], 'big'),
+        'gas': int.from_bytes(d[2], 'big'),
         'to':  web3.Web3.toChecksumAddress('0x' + d[3].hex()),
         'value': int.from_bytes(d[4], 'big'),
         'data': '0x' + d[5].hex(),
         'v': chain_id,
         'r': '0x',
         's': '0x',
+        'chainId': chain_id,
             }
 
